==> jc-1.4.0.tar.gz: javax/swing/plaf/ColorUIResource.h <==
// public class javax.swing.plaf.ColorUIResource

// class file dependencies
// @dep_class 2110d2173833fd4f java_awt_Color
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class abaf771e6b42dc39 javax_swing_plaf_ColorUIResource

// header file dependencies
// @dep_header java_awt_Color

#include "java/awt/Color.h"

#ifndef _JC_javax_swing_plaf_ColorUIResource_H_
#define _JC_javax_swing_plaf_ColorUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ColorUIResource$sub_refs	_jc_javax_swing_plaf_ColorUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs	_jc_javax_swing_plaf_ColorUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$refs	_jc_javax_swing_plaf_ColorUIResource$refs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$nonrefs	_jc_javax_swing_plaf_ColorUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$object	_jc_javax_swing_plaf_ColorUIResource$object;

typedef const struct _jc_javax_swing_plaf_ColorUIResource$vmethods	_jc_javax_swing_plaf_ColorUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ColorUIResource$vtable	_jc_javax_swing_plaf_ColorUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ColorUIResource$vtype	_jc_javax_swing_plaf_ColorUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$af232cd303340a48(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jfloat, jfloat, jfloat);
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jint);
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jint, jint, jint);
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_ColorUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ColorUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Color$vmethods	java_awt_Color;
	_jc_javax_swing_plaf_ColorUIResource$vmethods	javax_swing_plaf_ColorUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ColorUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ColorUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ColorUIResource$refs {
    _jc_javax_swing_plaf_ColorUIResource$sub_refs	javax_swing_plaf_ColorUIResource;
    _jc_java_awt_Color$sub_refs	java_awt_Color;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ColorUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Color$sub_nonrefs	java_awt_Color;
    _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs	javax_swing_plaf_ColorUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ColorUIResource$object {
	_jc_javax_swing_plaf_ColorUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ColorUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ColorUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ColorUIResource$vtype _jc_javax_swing_plaf_ColorUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ColorUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ColorUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ColorUIResource_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/ColorUIResource.h <==
// public class javax.swing.plaf.ColorUIResource

// class file dependencies
// @dep_class 2110d2173833fd4f java_awt_Color
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class abaf771e6b42dc39 javax_swing_plaf_ColorUIResource

// header file dependencies
// @dep_header java_awt_Color

#include "java/awt/Color.h"

#ifndef _JC_javax_swing_plaf_ColorUIResource_H_
#define _JC_javax_swing_plaf_ColorUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ColorUIResource$sub_refs	_jc_javax_swing_plaf_ColorUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs	_jc_javax_swing_plaf_ColorUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$refs	_jc_javax_swing_plaf_ColorUIResource$refs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$nonrefs	_jc_javax_swing_plaf_ColorUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ColorUIResource$object	_jc_javax_swing_plaf_ColorUIResource$object;

typedef const struct _jc_javax_swing_plaf_ColorUIResource$vmethods	_jc_javax_swing_plaf_ColorUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ColorUIResource$vtable	_jc_javax_swing_plaf_ColorUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ColorUIResource$vtype	_jc_javax_swing_plaf_ColorUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$af232cd303340a48(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jfloat, jfloat, jfloat) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_ColorUIResource$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_plaf_ColorUIResource$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_ColorUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ColorUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Color$vmethods	java_awt_Color;
	_jc_javax_swing_plaf_ColorUIResource$vmethods	javax_swing_plaf_ColorUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ColorUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ColorUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ColorUIResource$refs {
    _jc_javax_swing_plaf_ColorUIResource$sub_refs	javax_swing_plaf_ColorUIResource;
    _jc_java_awt_Color$sub_refs	java_awt_Color;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ColorUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Color$sub_nonrefs	java_awt_Color;
    _jc_javax_swing_plaf_ColorUIResource$sub_nonrefs	javax_swing_plaf_ColorUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ColorUIResource$object {
	_jc_javax_swing_plaf_ColorUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ColorUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ColorUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ColorUIResource$vtype _jc_javax_swing_plaf_ColorUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ColorUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ColorUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ColorUIResource_H_ */
